@@ -1,17 +1,23 @@
-// $Revision: 1.15 $$Date: 2005/01/12 21:35:09 $$Author: wsnyder $ -*- C++ -*-
+// $Revision: 1.15 $$Date: 2005-02-21 10:11:49 -0500 (Mon, 21 Feb 2005) $$Author: wsnyder $ -*- C++ -*-
 //======================================================================
 //
-// Copyright 2001-2005 by Wilson Snyder.  This program is free software;
-// you can redistribute it and/or modify it under the terms of either the GNU
-// General Public License or the Perl Artistic License.
-// 
+// Copyright 2001-2005 by Wilson Snyder <wsnyder@wsnyder.org>.  This
+// program is free software; you can redistribute it and/or modify it under
+// the terms of either the GNU Lesser General Public License or the Perl
+// Artistic License.
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 //======================================================================
-// DESCRIPTION: Vregs: Common classes used by all _class.h files
+///
+/// \file
+/// \brief Vregs: Common classes used by all _class.h files
+///
+/// AUTHOR:  Wilson Snyder
+///
 //======================================================================
 
 #ifndef _VREGSCLASS_H_
@@ -25,20 +31,20 @@ using namespace std;
 
 #ifndef _NINT32_T_
 #define _NINT32_T_ 1
-typedef void     nvoid_t;   // Pointer to data stored in network order
-typedef uint8_t  nint8_t;   // Always identical
-typedef uint16_t nint16_t;  // Uint stored in network order
-typedef uint32_t nint32_t;  // Uint stored in network order
-typedef uint64_t nint64_t;  // Uint stored in network order
+typedef void     nvoid_t;   ///< Pointer to data stored in network order
+typedef uint8_t  nint8_t;   ///< Uint stored in network order, bytes are always identical
+typedef uint16_t nint16_t;  ///< Uint stored in network order
+typedef uint32_t nint32_t;  ///< Uint stored in network order
+typedef uint64_t nint64_t;  ///< Uint stored in network order
 #endif
 
 #ifndef _ADDRESS_T
 //typedef uint64_t address_t;
-typedef uint32_t address_t;
+typedef uint32_t address_t; ///< Register address
 #endif
 
 #ifndef	_SIZE64_T
-typedef address_t size64_t;
+typedef address_t size64_t; ///< Size of register in bytes
 #define _SIZE64_T
 #endif
 
@@ -46,11 +52,13 @@ typedef address_t size64_t;
 // Macros to control compile-time debugging options
 
 #ifndef VREGS_ENUM_DEF_INITTER
+/// Initialize a enumeration value
 # define VREGS_ENUM_DEF_INITTER(invalidValue)
 //	: m_e(invalidValue)
 #endif
 
 #ifndef VREGS_WORDIDX_CHK
+/// Check a word index is within bounds
 # define VREGS_WORDIDX_CHK(TypeName, numWords, idx)
 //	{ if (idx >= numWords)
 //	   cerr <<"Setter " #TypeName ".w(" <<idx <<", val) arg1 is beyond "
@@ -58,17 +66,18 @@ typedef address_t size64_t;
 #endif
 
 #ifndef VREGS_SETFIELD_CHK
+/// Check a field index is within bounds
 # define VREGS_SETFIELD_CHK(identStr, value, u_maxVal)
 //	{ assert(value <= u_maxVal); } // identStr is "Structname.fieldName"
 #endif
 
 #ifndef VREGS_STRUCT_DEF_CTOR
+/// Initalize a structure member
 # define VREGS_STRUCT_DEF_CTOR(TypeName, numWords)
 //	TypeName () { for (int i=0; i<numWords; i++) w(i, 0xdeadbeef); }
 #endif
 
 //======================================================================
-// VregsOstream
 
 #ifndef COUT
 #define COUT cout
@@ -77,16 +86,21 @@ typedef address_t size64_t;
 #define OStream ostream
 #endif
 
-// This class is used so we can do:
-//	COUT << "structure= " << vregs_object.dump() << " etc...";
-// To get the dump() to work, the dump() function should return a VregsOstream object
-// templated to the type of the vregs_object.  However, that causes compile times
-// to explode, so we just store a void* and cast in the vregs output.
-// We then define a operator to take the VregsOstream object and put it out.
+//======================================================================
+// VregsOstream
+/// Vregs Output Stream for dumping of structures in << operators.
+////
+/// This class is used so we can do:
+///	COUT << "structure= " << vregs_object.dump() << " etc...";
+/// To get the dump() to work, the dump() function should return a VregsOstream object
+/// templated to the type of the vregs_object.  However, that causes compile times
+/// to explode, so we just store a void* and cast in the vregs output.
+/// We then define a operator to take the VregsOstream object and put it out.
+
 template <class T>
 class VregsOstream {
-    const void*	m_obj;
-    const char*	m_prefix;
+    const void*	m_obj;		///< Object to dump
+    const char*	m_prefix;	///< Text to place in front of new lines
 public:
     inline VregsOstream(const void* obj, const char* prefix)
 	: m_obj(obj), m_prefix(prefix) {};
